@@ -1,20 +1,24 @@
 # Copyright 2020-2021 Cambridge Quantum Computing
 #
-# You may not use this file except in compliance with the Licence.
-# You may obtain a copy of the Licence in the LICENCE file accompanying
-# these documents or at:
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-#     https://cqcl.github.io/pytket/build/html/licence.html
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
+from typing import Optional, List
 from qiskit.assembler import disassemble  # type: ignore
 from qiskit.providers import BaseBackend  # type: ignore
 from qiskit.providers.models import QasmBackendConfiguration  # type: ignore
 from qiskit.qobj import QasmQobj  # type: ignore
-
 from pytket.extensions.qiskit.qiskit_convert import qiskit_to_tk, _gate_str_2_optype_rev
 from pytket.extensions.qiskit.tket_job import TketJob
-
-from pytket.circuit import OpType  # type: ignore
 from pytket.backends import Backend
 from pytket.passes import BasePass  # type: ignore
 from pytket.predicates import (  # type: ignore
@@ -23,8 +27,6 @@ from pytket.predicates import (  # type: ignore
     CompilationUnit,
 )
 
-from typing import Optional, List
-
 
 def _extract_basis_gates(backend: Backend) -> List[str]:
     for pred in backend.required_predicates:
